pub enum UnresolvedVersionSpec {
Canary,
Alias(String),
Req(VersionReq),
ReqAny(Vec<VersionReq>),
Version(Version),
}Expand description
Represents an unresolved version or alias that must be resolved to a fully-qualified and semantic result.
Variants
Canary
A special canary target.
Alias(String)
An alias that is used as a map to a version.
Req(VersionReq)
A partial version, requirement, or range (^, ~, etc).
ReqAny(Vec<VersionReq>)
A list of requirements to match any against (joined by ||).
Version(Version)
A fully-qualified semantic version.
Implementations
sourceimpl UnresolvedVersionSpec
impl UnresolvedVersionSpec
sourcepub fn parse<T>(value: T) -> Result<UnresolvedVersionSpec, Error>
pub fn parse<T>(value: T) -> Result<UnresolvedVersionSpec, Error>
Parse the provided string into an unresolved specification based on the following rules, in order:
- If the value “canary”, map as
Canaryvariant. - If an alpha-numeric value that starts with a character, map as
Alias. - If contains
||, split and parse each item withVersionReq, and map asReqAny. - If contains
,or(space), parse withVersionReq, and map asReq. - If starts with
=,^,~,>,<, or*, parse withVersionReq, and map asReq. - Else parse with
Version, and map asVersion.
sourcepub fn is_alias<A>(&self, name: A) -> bool
pub fn is_alias<A>(&self, name: A) -> bool
Return true if the provided alias matches the current specification.
sourcepub fn is_latest(&self) -> bool
pub fn is_latest(&self) -> bool
Return true if the current specification is the “latest” alias.
sourcepub fn to_resolved_spec(&self) -> VersionSpec
pub fn to_resolved_spec(&self) -> VersionSpec
Convert the current unresolved specification to a resolved specification.
Note that this does not actually resolve or validate against a manifest,
and instead simply constructs the VersionSpec.
Furthermore, the Req and ReqAny variants will panic, as they are not
resolved or valid versions.